==> man-db_2.3.16-4.tar.gz: man-db-2.3.16/acconfig.h <==
/* define if you want to remove debugging assertions */
#undef NDEBUG

/* define to the version of the OS, if you have a debian gnu/linux system */
#undef DEBIAN

/* define to the full version of the program, if you have a debian gnu/linux system */
#undef DEBVER

/* define to the full email address of the debian maintainer, if you have a debian gnu/linux system */
#undef DEBMAINT

/* define if you have, and want to use, ndbm interface routines */ 
#undef NDBM

/* define if you have, and want to use, gdbm interface routines */ 
#undef GDBM

/* define if you have, and want to use, db (binary tree) interface routines */
#undef BTREE

/* define if you have, and want to use, db (from libc) interface routines */
#undef DB_ON_LIBC

/* define if you have troff */
#undef HAS_TROFF

/* define if you don't have nroff */
#undef NROFF_MISSING

/* define as the setuid owner of man or undefine if not installing setuid */
#undef SECURE_MAN_UID

/* define if you have the setlocale() function */
#undef HAVE_SETLOCALE

/* define if you have the re_comp and re_exec BSD regex routines */
#undef BSD_REGEX

/* define if you have the regcomp and regexec POSIX regex routines */
#undef POSIX_REGEX

/* define if nroff is GNU nroff */
#undef GNU_NROFF

/* define if we are using groff as troff */
#undef TROFF_IS_GROFF

/* define if your sprintf function returns a count of converted characters */
#undef ANSI_SPRINTF

/* define COMP_CAT if you have compressors and want to support compressed
   cat files */
#undef COMP_CAT

/* define COMP_SRC if you have compressors and want to support compressed
   manual source */
#undef COMP_SRC

/* define if your pclose function doesn't handle multiple streams properly */
#undef BROKEN_PCLOSE

/* define if using <fnmatch.h> rather than "lib/fnmatch.h" */
#undef HAVE_FNMATCH_H

/* define if using <getopt.h> rather than "lib/getopt.h" */
#undef HAVE_GETOPT_H

/* define if using <glob.h> rather than "lib/glob.h" */
#undef HAVE_GLOB_H

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

/* Define to 1 if stpcpy function is available.  */
#undef HAVE_STPCPY

/* Define to the name of the distribution.  */
#undef PACKAGE

/* Define to the version of the distribution.  */
#undef VERSION

==> man-db-2.4.0.tar.gz: man-db-2.4.0/acconfig.h <==
/* define if you want to remove debugging assertions */
#undef NDEBUG

/* define if you have, and want to use, ndbm interface routines */ 
#undef NDBM

/* define if you have, and want to use, gdbm interface routines */ 
#undef GDBM

/* define if you have, and want to use, Berkeley database library */
#undef BTREE

/* define if you have, and want to use, Berkeley database header files */
#undef BDB_H

/* define if you have troff */
#undef HAS_TROFF

/* define if you don't have nroff */
#undef NROFF_MISSING

/* define as the setuid owner of man or undefine if not installing setuid */
#undef SECURE_MAN_UID

/* define if you have the setlocale() function */
#undef HAVE_SETLOCALE

/* define if you have the re_comp and re_exec BSD regex routines */
#undef BSD_REGEX

/* define if you have the regcomp and regexec POSIX regex routines */
#undef POSIX_REGEX

/* define if nroff is GNU nroff */
#undef GNU_NROFF

/* define if we are using groff as troff */
#undef TROFF_IS_GROFF

/* define if your sprintf function returns a count of converted characters */
#undef ANSI_SPRINTF

/* define COMP_CAT if you have compressors and want to support compressed
   cat files */
#undef COMP_CAT

/* define COMP_SRC if you have compressors and want to support compressed
   manual source */
#undef COMP_SRC

/* define if using <fnmatch.h> rather than "lib/fnmatch.h" */
#undef HAVE_FNMATCH_H

/* define if using <getopt.h> rather than "lib/getopt.h" */
#undef HAVE_GETOPT_H

/* define if using <glob.h> rather than "lib/glob.h" */
#undef HAVE_GLOB_H

/* Define to the name of the distribution.  */
#undef PACKAGE

/* Define to the version of the distribution.  */
#undef VERSION

/* Define to the manual page hierarchy organization(s) in use. */
#undef MANDIR_LAYOUT
